pub struct ListNotebookMetadataFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListNotebookMetadata.
Displays the notebook files for the specified workgroup in paginated format.
Implementations
Sourceimpl ListNotebookMetadataFluentBuilder
impl ListNotebookMetadataFluentBuilder
Sourcepub fn as_input(&self) -> &ListNotebookMetadataInputBuilder
pub fn as_input(&self) -> &ListNotebookMetadataInputBuilder
Access the ListNotebookMetadata as a reference.
Sourcepub async fn send(
self,
) -> Result<ListNotebookMetadataOutput, SdkError<ListNotebookMetadataError, HttpResponse>>
pub async fn send( self, ) -> Result<ListNotebookMetadataOutput, SdkError<ListNotebookMetadataError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListNotebookMetadataOutput, ListNotebookMetadataError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListNotebookMetadataOutput, ListNotebookMetadataError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn filters(self, input: FilterDefinition) -> Self
pub fn filters(self, input: FilterDefinition) -> Self
Search filter string.
Sourcepub fn set_filters(self, input: Option<FilterDefinition>) -> Self
pub fn set_filters(self, input: Option<FilterDefinition>) -> Self
Search filter string.
Sourcepub fn get_filters(&self) -> &Option<FilterDefinition>
pub fn get_filters(&self) -> &Option<FilterDefinition>
Search filter string.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
Specifies the maximum number of results to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
Specifies the maximum number of results to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
Specifies the maximum number of results to return.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The name of the Spark enabled workgroup to retrieve notebook metadata for.
Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The name of the Spark enabled workgroup to retrieve notebook metadata for.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The name of the Spark enabled workgroup to retrieve notebook metadata for.