#[non_exhaustive]pub struct ListNotebookMetadataOutputBuilder { /* private fields */ }Expand description
A builder for ListNotebookMetadataOutput.
Implementations
Sourceimpl ListNotebookMetadataOutputBuilder
impl ListNotebookMetadataOutputBuilder
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn notebook_metadata_list(self, input: NotebookMetadata) -> Self
pub fn notebook_metadata_list(self, input: NotebookMetadata) -> Self
Appends an item to notebook_metadata_list.
To override the contents of this collection use set_notebook_metadata_list.
The list of notebook metadata for the specified workgroup.
Sourcepub fn set_notebook_metadata_list(
self,
input: Option<Vec<NotebookMetadata>>,
) -> Self
pub fn set_notebook_metadata_list( self, input: Option<Vec<NotebookMetadata>>, ) -> Self
The list of notebook metadata for the specified workgroup.
Sourcepub fn get_notebook_metadata_list(&self) -> &Option<Vec<NotebookMetadata>>
pub fn get_notebook_metadata_list(&self) -> &Option<Vec<NotebookMetadata>>
The list of notebook metadata for the specified workgroup.
Sourcepub fn build(self) -> ListNotebookMetadataOutput
pub fn build(self) -> ListNotebookMetadataOutput
Consumes the builder and constructs a ListNotebookMetadataOutput.